@@ -15,7 +15,12 @@ from league_data.models import Champion, Skin
 
 
 class Explorer:
-    """Explore e entenda facilmente os dados dos campeões."""
+    """Explore e entenda facilmente os dados dos campeões.
+
+    Attributes:
+        data (dict): Dados da Riot.
+        champions (dict): Dicionário de campeões.
+    """
 
     def get_champion(self, name: str) -> Champion | None:
         """Retorna o objeto do campeão, caso exista.
@@ -61,10 +66,17 @@ class Explorer:
         """Retorna a URL do campeão ou da skin desejada com base em seus IDS."""
         return f"https://raw.communitydragon.org/latest/plugins/rcp-be-lol-game-data/global/default/v1/champion-splashes/{champion_id}/{skin_id}.jpg"
 
-    def __init__(self, data: dict) -> None:
-        """Reformula os dados que recebe como parâmetro."""
-        self.data = data
-        self.champions = self.__get_champions()
+    def __init__(self, data: dict, champions: dict | None = None) -> None:
+        """Reformula os dados que recebe como parâmetro.
+
+        Caso não receba os champions, será requisitado automaticamente.
+
+        Args:
+            data (dict): Dados da Riot, gerados pelo League.
+            champions (dict, optional): Dicionário de campeões, gerados pelo Explorer.
+        """
+        self.data = data  # dados gerados da classe League
+        self.champions = champions or self.__get_champions()
 
     def __getitem__(self, name: str) -> Champion | Skin | None:
         """Retorna os dados do campeão ou skin, caso exista.
@@ -77,10 +89,8 @@ class Explorer:
             Skin (Skin): Objeto da skin encontrada.
             None (None): Nenhum item foi encontrado.
         """
-        if champion := self.get_champion(name):
-            return champion
-
-        return self.get_skin(name)
+        champion = self.get_champion(name)
+        return champion or self.get_skin(name)
 
     def __get_champions(self) -> dict:
         champions = {}
